@@ -1,10 +1,11 @@
 use strict;
 use warnings;
 package Math::Shape::Circle;
-$Math::Shape::Circle::VERSION = '0.09';
+$Math::Shape::Circle::VERSION = '0.1';
 use 5.008;
 use Carp;
 use Math::Shape::Vector;
+use Math::Shape::Rectangle;
 
 # ABSTRACT: a 2d circle
 
@@ -57,6 +58,27 @@ sub collides
             && 0 <= $p->dot_product($d)
             ? 1 : 0;
     }
+    elsif ($other_obj->isa('Math::Shape::Rectangle'))
+    {
+        my $clamped_vector = $other_obj->clamp($self->{center});
+
+        $self->collides($clamped_vector);
+    }
+    elsif ($other_obj->isa('Math::Shape::OrientedRectangle'))
+    {
+        # transform OrientedRectangle into Rectangle
+        my $r_size = $other_obj->{half_extend}->multiply(2);
+        my $lr = Math::Shape::Rectangle->new(0, 0, $r_size->{x}, $r_size->{y});
+
+        # transform $self into local Circle in coordinates of other_obj
+        my $distance = $self->{center}->subtract_vector($other_obj->{center});
+        $distance = $distance->rotate(- $other_obj->{rotation});
+        my $center = $distance->add_vector($other_obj->{half_extend});
+        my $lc = Math::Shape::Circle->new($center->{x}, $center->{y}, $self->{radius});
+
+        # check local objects collide
+        $lc->collides($lr);
+    }
     else
     {
         croak 'collides must be called with a Math::Shape::Vector library object';
@@ -76,7 +98,7 @@ Math::Shape::Circle - a 2d circle
 
 =head1 VERSION
 
-version 0.09
+version 0.1
 
 =head1 METHODS
 
