@@ -1,15 +1,16 @@
 use strict;
 use warnings;
 package Math::Shape::Utils;
-$Math::Shape::Utils::VERSION = '0.09';
+$Math::Shape::Utils::VERSION = '0.1';
 use Math::Trig ':pi';
+use Carp 'croak';
 
 # ABSTRACT: Utility methods used by the Math::Shape::Vector module
 
 BEGIN {
     require Exporter;
     use base qw(Exporter);
-    our @EXPORT = qw(degrees_to_radians radians_to_degrees overlap equal_floats minimum maximum);
+    our @EXPORT = qw(degrees_to_radians radians_to_degrees overlap equal_floats minimum maximum clamp_on_range);
     our @EXPORT_OK = ();
 }
 
@@ -45,6 +46,25 @@ sub maximum
     $_[0] > $_[1] ? $_[0] : $_[1];
 }
 
+sub clamp_on_range
+{
+    croak 'clamp_on_range() called without enough args. It requires 3 arguments: x, min & max' unless @_ == 3;
+    my ($x, $min, $max) = @_;
+
+    if ($x < $min)
+    {
+        $min;
+    }
+    elsif ($x > $max)
+    {
+        $max;
+    }
+    else
+    {
+        $x;
+    }
+}
+
 1;
 
 __END__
@@ -59,7 +79,7 @@ Math::Shape::Utils - Utility methods used by the Math::Shape::Vector module
 
 =head1 VERSION
 
-version 0.09
+version 0.1
 
 =head1 AUTHOR
 
